--- title: "wallaroo.orchestration" type: docs linkTitle: "wallaroo.orchestration" ---
class Orchestration(wallaroo.object.Object):

An Orchestration object that represents some user-defined code that has been packaged into a container and can be deployed.

Orchestration( client: wallaroo.client.Client, data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

@staticmethod
def list_orchestrations( client: wallaroo.client.Client) -> List[wallaroo.orchestration.Orchestration]:
@staticmethod
def upload( client: wallaroo.client.Client, name: Optional[str] = None, bytes_buffer: Optional[bytes] = None, path: Optional[str] = None, file_name: Optional[str] = None) -> wallaroo.orchestration.Orchestration:
def run_once( self, name: Optional[str], json_args: Dict[Any, Any] = {}, timeout: Optional[int] = None, debug: Optional[bool] = False):

Runs this Orchestration once.

###### Parameters

- name str A descriptive identifier for this run.
- json_args Dict[Any, Any] A JSON object containing deploy-specific arguments.
- timeout Optional[int] A timeout in seconds. Any instance of this orchestration that is running for longer than this specified time will be automatically killed.
- debug Optional[bool] Produce extra debugging output about the run

###### Returns

> A metadata object associated with the deploy Task

def run_scheduled( self, name: str, schedule: str, json_args: Dict[Any, Any] = {}, timeout: Optional[int] = None, debug: Optional[bool] = False):

Runs this Orchestration on a cron schedule.

###### Parameters

- name str A descriptive identifier for this run.
- schedule str A cron-style scheduling string, e.g. "* * * * " or "/15 * * * *"
- json_args Dict[Any, Any] A JSON object containing deploy-specific arguments.
- timeout Optional[int] A timeout in seconds. Any single instance of this orchestration that is running for longer than this specified time will be automatically killed. Future runs will still be scheduled.
- debug Optional[bool] Produce extra debugging output about the run

###### Returns

> A metadata object associated with the deploy Task

def id(*args, **kwargs):
def name(*args, **kwargs):
def file_name(*args, **kwargs):
def sha(*args, **kwargs):
def status(*args, **kwargs):
def created_at(*args, **kwargs):
def updated_at(*args, **kwargs):
def workspace_id(*args, **kwargs):
def task(*args, **kwargs):
def list_tasks(self):
class OrchestrationList(typing.List[wallaroo.orchestration.Orchestration]):

Wraps a list of pipelines for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort

class OrchestrationUploadFailed(builtins.Exception):

Raised when uploading an Orchestration fails due to a backend issue.

OrchestrationUploadFailed(e)

##### Inherited Members

builtins.BaseException
  with_traceback
  args

class OrchestrationMissingFile(builtins.Exception):

Raised when uploading an Orchestration without providing a file-like object.

OrchestrationMissingFile()

##### Inherited Members

builtins.BaseException
  with_traceback
  args

class OrchestrationDeployOneshotFailed(builtins.Exception):

Raised when deploying an Orchestration fails due to a backend issue.

OrchestrationDeployOneshotFailed(e)

##### Inherited Members

builtins.BaseException
  with_traceback
  args